#!/bin/bash
# 
# check-muse-hardware.sh
#
# this is run during rc.sysinit to determine the hardware configuration
# and tweak the system accordingly
#

if ! [ -e /var/run ] || ! [ -e /proc/ioports ]; then
	echo "/var/run or /proc/ioports not found - failed to set hardware-version"
	exit 1
fi

if fgrep -q Realtek /proc/ioports; then 
	# AM37 motherboard, COM 1, 8139
	REVISION="Rev A"
	FRONT_PANEL=/dev/ttyS1
	cp -f /etc/modules.conf.reva /etc/modules.conf
else
	if fgrep -q 1106:7205 /proc/iomem; then
		# A7V8X (or AM39) motherboard
		REVISION="Rev B"
	elif fgrep -q 1106:3108 /proc/iomem; then
		# K8MM-V (or KV-85) motherboard


		#Check for ML-44, no RAM check requirement for Pro
		if grep -q "ML-44" /proc/cpuinfo; then
			REVISION="Receptor PRO"
		else
			REVISION="Rev C"
		fi

	else
		# Unknown motherboard
		REVISION="Rev X"
	fi

	if fgrep -q "USB <-> Serial" /proc/bus/usb/devices; then
		# USB to Serial converter
		FRONT_PANEL=/dev/ttyUSB0
	else
		# front panel on COM 0
		FRONT_PANEL=/dev/ttyS0
	fi

	if fgrep -q 1106:3119 /proc/ioports; then
		# VT612x GbLAN
		cp -f /etc/modules.conf.vget /etc/modules.conf
	else
		# probably a VT6102
		cp -f /etc/modules.conf.revb /etc/modules.conf
	fi
fi

ln -sf $FRONT_PANEL /dev/panel

echo "1.0 ($REVISION)" > /var/run/muse-hardware-version

rm -f /etc/asound.state

#Check for clock skew and reset the date if detected
LAST_BOOT_LOG_FILE="/var/cache/receptor/last-boot-time"
DATE_FMT="+%Y%m%d%H%M"

if [ ! -f "$LAST_BOOT_LOG_FILE" ]
then
	logger "No last boot file found.  Creating with current time."
	echo `date $DATE_FMT` > $LAST_BOOT_LOG_FILE
fi

SKEW_CHECK_TIME=`cat $LAST_BOOT_LOG_FILE`

# If we are more than a year older than the check time, the clock is
# considered skewed
let "TIME_DIFF=$SKEW_CHECK_TIME - `date $DATE_FMT`"
if [ "$TIME_DIFF" -gt 99999999 ] 
then
	date `echo $SKEW_CHECK_TIME | cut -b5-12``echo $SKEW_CHECK_TIME | cut -b1-4` > /dev/null
	logger "Date skew detected.  Setting to `date`"
else
	echo `date $DATE_FMT` > $LAST_BOOT_LOG_FILE
fi

exit 0
