#! /bin/bash
#
# install-mrpk - handle installation of an MRPK file via RPM
#

if [ $# -ne 1 ] || ! [ -f "$1" ]; then
	echo "usage: install-mrpk.sh FILE"
	echo "where FILE is an MRPK file to install via RPM. MRPKs are bzip2"
	echo "tar archives of RPM files."
	exit 1
fi

TEMPORARY_INSTALL_PATH=/var/tmp/system-interface-install

# start from scratch
rm -rf $TEMPORARY_INSTALL_PATH
if ! mkdir $TEMPORARY_INSTALL_PATH; then
	exit 1
fi

# extract everything in the tarball - hide tar's verbose output 
if ! tar --extract --bzip --directory=$TEMPORARY_INSTALL_PATH \
		--file="$1" > /dev/null; then
	echo "Failed: unrecognized '$1'"
	exit 1
fi

# remove anything which isn't an installable RPM
cd $TEMPORARY_INSTALL_PATH
for FILE in `ls *`; do 
	# ignore normal RPM output, but print errors
	if ! rpm -U --test --nodeps $FILE > /dev/null ; then 
		rm $FILE
	fi
done

# that was everything - abandon ship
if ! ls $TEMPORARY_INSTALL_PATH/* 2> /dev/null > /dev/null; then
	echo "Failed: bad or old '$1'"
	exit 1
fi

# let RPM at it - and have it print outcome and errors
if ! rpm -Uv $TEMPORARY_INSTALL_PATH/*; then
	exit 1
fi

rm -rf $TEMPORARY_INSTALL_PATH
exit 0
