#!/bin/bash
#
# install-receptor-package.sh - install a package for receptor
#

DEFAULT_DIR="/c/Drop Installers Here"
LOGFILE=/var/log/install-receptor-package.log

if [ $# -ne 1 ]; then
	echo "usage: install-receptor-package.sh FILE
Where FILE is an RPM or MRPK file to install with rpm -U or install-mrpk.sh.
FILE is moved to:
   MUSE_INSTALLERS_PATH/Installed on success or
   MUSE_INSTALLERS_PATH/Failed on failure.

Default MUSE_INSTALLERS_PATH is $DEFAULT_DIR.
A log file is kept at $LOGFILE."
	exit 1
fi

# log results here
echo -e "\n*** Installing '$1' - `date +%F\ %r`" >> $LOGFILE

if ! [ -f "$1" ]; then
	echo "Failed: not a file" | tee -a $LOGFILE
	exit 1
fi

if [ ! "$MUSE_INSTALLERS_DIRECTORY" ]; then
	MUSE_INSTALLERS_DIRECTORY=$DEFAULT_DIR
fi

# is the file an RPM? rpm wants escaped spaces along with double quotes for its path
SUCCESS=
if rpm -qp \""`echo $1 | sed 's/ /\\ /g'`"\" 2> /dev/null > /dev/null; then
	# if it is an RPM, update it - let RPM print its progress and errors
	if rpm -Uv \""`echo $1 | sed 's/ /\\ /g'`"\" >> $LOGFILE 2>&1; then
		SUCCESS="yes"
	fi
# try an MRPK - script prints its own errors
elif /usr/bin/install-mrpk.sh "$1" >> $LOGFILE 2>&1; then
	SUCCESS="yes"
fi

# update the rpm package list
if [ "$SUCCESS" ]; then 
	/etc/cron.daily/rpm
fi

# what to do with the file
if [ "$SUCCESS" ]; then
	INSTALLED_DIR="$MUSE_INSTALLERS_DIRECTORY/Installed"
	if [ -d "$INSTALLED_DIR" ]; then
		mv "$1" "$INSTALLED_DIR" 2>> $LOGFILE
	fi

	echo "--> Installed: $1 - `date +%r`" >> $LOGFILE
else
	FAILED_DIR="$MUSE_INSTALLERS_DIRECTORY/Failed"
	if [ -d "$FAILED_DIR" ]; then
		mv "$1" "$FAILED_DIR" 2>> $LOGFILE
	fi
	echo "--> Failed: $1 - `date +%r`" >> $LOGFILE
fi

exit 0
