#! /bin/bash
#
# Rename the AppleTalk volume
#

#
# check out arguments (0 or 1)
#
if [ $# -gt 1 ]; then
        echo "usage: rename-atalk.sh [NAME]";
        echo "where NAME is the name of the AppleTalk volume";
        echo "If no argument, then hostname is used";
        exit 1;
fi

#
# The AppleTalk name is the first argument or the hostname
#
if [ $# -eq 1 ]; then
	ATALK_NAME=$1;
else      
	ATALK_NAME=`/bin/hostname | cut -d . -f 1`;
fi

#
# Find out if config files are in /etc/netatalk or in /usr/etc/netatalk
#
if [ -d /etc/netatalk ]; then
	ATALK_CONF_DIR="/etc/netatalk";
elif [ -d /usr/etc/netatalk ]; then
	ATALK_CONF_DIR="/usr/etc/netatalk";
fi

if [ -z ${ATALK_CONF_DIR} ]; then
	echo No netatalk config directory;
	exit 1;
fi

#
# Change the name in afpd.conf
#
CONF_FILE="${ATALK_CONF_DIR}/afpd.conf"
if [ -f ${CONF_FILE} ]; then
	TEMP_FILE=`mktemp ${CONF_FILE}.XXXXXX` || exit 1;
	chmod 644 ${TEMP_FILE}
	SED_SCRIPT="s|\".*\" -uamlist uams_guest.so|\"${ATALK_NAME}\" -uamlist uams_guest.so|";
	sed  "${SED_SCRIPT}" ${CONF_FILE} > ${TEMP_FILE};
	mv ${TEMP_FILE} ${CONF_FILE};
fi

#
# Change the name in AppleVolumes.default
#
CONF_FILE="${ATALK_CONF_DIR}/AppleVolumes.default"
if [ -f ${CONF_FILE} ]; then
	TEMP_FILE=`mktemp ${CONF_FILE}.XXXXXX` || exit 1
	chmod 644 ${TEMP_FILE}
	SED_SCRIPT="s|/c .* allow:nobody|/c \"${ATALK_NAME}\" allow:nobody|"
	sed  "${SED_SCRIPT}" ${CONF_FILE} > ${TEMP_FILE}
	mv ${TEMP_FILE} ${CONF_FILE}
fi

#
# Restart atalk
#
#/etc/rc.d/init.d/atalk restart

exit 0
