#!/bin/bash
#
# volume-info.sh VOLUME
# Prints bytes used and total bytes for the given VOLUME.
# Written to support rm-host's SystemInterface::VolumeInfo call.
#

if [ $# -eq 0 ]; then
	echo usage: volume-usage.sh VOLUME	
	echo Prints bytes used and total bytes for the given VOLUME,
	echo where VOLUME is the mountpoint for a hard disk device.
	exit 1
fi
if [ ! -d $1 ]; then
	echo Not a directory: $1 >&2
	exit 1
fi

# todo: mustn't be a | or regexp char in $1 
NAME=$1

DEVICE=`/bin/sed -n "s|^\(/dev/hd.*\) $NAME .*|\1|p" /etc/mtab`
if [ -z "$DEVICE" ]; then
	echo Not found: $1 >&2
	exit 1
fi

RESULT=`df $DEVICE | tail -1 | tr -s " "`
let TOTAL=`grep -e "hda$" /proc/partitions | tr -s " " | cut -f4 -d " "`*1024
let USED=`echo $RESULT | cut -f 3 -d " "`*1024
let AVAILABLE=`echo $RESULT | cut -f 4 -d " "`*1024

echo $USED used
echo $AVAILABLE available
echo $TOTAL total
exit 0
